.. QM sim documentation master file, created by
   sphinx-quickstart on Sun Apr 30 17:04:27 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

QM-sim
======

A python library for simulation of quantum mechanical systems.


.. mdinclude:: ../../README.md
   :start-line: 7
   :end-line: 20

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   usage
   api
   examples
   contribution

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
